@@ -101,8 +101,6 @@ is_close:{is_close}
 
             self.sock.sendall(message_log.encode('utf8'))
         except Exception:
-            # 这里发送失败可能是因为服务端进程崩溃, 网络问题,
-            # 可以尝试不做处理, 避免因为日志客户端的异常影响到使用它的应用程序.
             # TODO: 添加发送失败报警
             pass
             raise
@@ -117,8 +115,8 @@ is_close:{is_close}
         message = message.replace('\n', '')
 
         caller = getframeinfo(stack()[1][0])
-        # self.__send(message=message, is_close=0, filename=caller.filename, lineno=caller.lineno)
-        self.pool.submit(self.__send, message=message, is_close=0, filename=caller.filename, lineno=caller.lineno)
+        self.__send(message=message, is_close=0, filename=caller.filename, lineno=caller.lineno)
+        # self.pool.submit(self.__send, message=message, is_close=0, filename=caller.filename, lineno=caller.lineno)
 
     def close(self):
         """
